/* find.h - find files as a front end to find ... -exec grep ...
   Copyright (C) 1996-2000 Paul Sheer

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307, USA.
 */

#ifndef _FIND_H
#define _FIND_H

#define INPUTS_WITH_OPTIONS_BROWSE_LOAD		(1 << 0)
#define INPUTS_WITH_OPTIONS_BROWSE_SAVE		(1 << 6)
#define INPUTS_WITH_OPTIONS_BROWSE_DIR		(1 << 12)

#define INPUTS_WITH_OPTIONS_BROWSE_LOAD_1	(INPUTS_WITH_OPTIONS_BROWSE_LOAD << 0)
#define INPUTS_WITH_OPTIONS_BROWSE_LOAD_2	(INPUTS_WITH_OPTIONS_BROWSE_LOAD << 1)
#define INPUTS_WITH_OPTIONS_BROWSE_LOAD_3	(INPUTS_WITH_OPTIONS_BROWSE_LOAD << 2)
#define INPUTS_WITH_OPTIONS_BROWSE_LOAD_4	(INPUTS_WITH_OPTIONS_BROWSE_LOAD << 3)
#define INPUTS_WITH_OPTIONS_BROWSE_LOAD_5	(INPUTS_WITH_OPTIONS_BROWSE_LOAD << 4)
#define INPUTS_WITH_OPTIONS_BROWSE_LOAD_6	(INPUTS_WITH_OPTIONS_BROWSE_LOAD << 5)

#define INPUTS_WITH_OPTIONS_BROWSE_SAVE_1	(INPUTS_WITH_OPTIONS_BROWSE_SAVE << 0)
#define INPUTS_WITH_OPTIONS_BROWSE_SAVE_2	(INPUTS_WITH_OPTIONS_BROWSE_SAVE << 1)
#define INPUTS_WITH_OPTIONS_BROWSE_SAVE_3	(INPUTS_WITH_OPTIONS_BROWSE_SAVE << 2)
#define INPUTS_WITH_OPTIONS_BROWSE_SAVE_4	(INPUTS_WITH_OPTIONS_BROWSE_SAVE << 3)
#define INPUTS_WITH_OPTIONS_BROWSE_SAVE_5	(INPUTS_WITH_OPTIONS_BROWSE_SAVE << 4)
#define INPUTS_WITH_OPTIONS_BROWSE_SAVE_6	(INPUTS_WITH_OPTIONS_BROWSE_SAVE << 5)

#define INPUTS_WITH_OPTIONS_BROWSE_DIR_1	(INPUTS_WITH_OPTIONS_BROWSE_DIR << 0)
#define INPUTS_WITH_OPTIONS_BROWSE_DIR_2	(INPUTS_WITH_OPTIONS_BROWSE_DIR << 1)
#define INPUTS_WITH_OPTIONS_BROWSE_DIR_3	(INPUTS_WITH_OPTIONS_BROWSE_DIR << 2)
#define INPUTS_WITH_OPTIONS_BROWSE_DIR_4	(INPUTS_WITH_OPTIONS_BROWSE_DIR << 3)
#define INPUTS_WITH_OPTIONS_BROWSE_DIR_5	(INPUTS_WITH_OPTIONS_BROWSE_DIR << 4)
#define INPUTS_WITH_OPTIONS_BROWSE_DIR_6	(INPUTS_WITH_OPTIONS_BROWSE_DIR << 5)

#define INPUTS_WITH_OPTIONS_FREE_STRINGS	0x10000000

int CInputsWithOptions (Window parent, int x, int y, const char *heading,
	    char **inputs[], char *input_labels[], char *input_names[],
    char *input_tool_hint[], int *check_values[], char *check_labels[],
			char *check_tool_hints[], int options, int width);

#endif				/* ! FIND_H */

